SPARTOO.PT, O meu Cesto

A Spartoo utiliza cookies. Ao continuar a navegar no site, aceita a utilização dos mesmos.
Aceito.
Serviço cliente 308 802 547
Segunda - Sexta : 8h - 17h
A minha conta | As minhas encomendas | Como fazer uma devolução? | Ganhe 10 euros | Os meus Favoritos | Ajuda
Início
entrega
gratuita
em 7 dias úteis
devolução
gratuita
até 30 dias
O meu cesto (0)

# Identificação

## Já sou CLIENTE, identifico-me

E-mail
Palavra-passe
Esqueceu-se da palavra passe? Clique aqui.
Tem uma conta facebook ? Clique aqui.

## Sou um NOVO CLIENTE, crio a minha conta

E-mail
Palavra-passe
Segurança da palavra-passe
Sugestões:

- Utilize no mínimo 6 caracteres
- Tente inserir pelo menos um número (0-9)
- Tente adicionar pelo menos um símbolo (!@#$%^&*)
- Tente incluir letras maiúsculas (A-Z) e minúsculas (a-z).

Confirmar palavra-passe
Género
Senhor Senhora
Nome
Apelido
Data de nascimento
/
/
Telefone
Morada
Complemento de morada opcional
Código postal
Localidade
País
E-mail do seu padrinho opcional
Desejo receber os planos dos parceiros de Spartoo Opcional
Política de privacidade
A palavra-passe deve conter pelo menos 5 caracteres
Ao registar-se beneficiará de todas as promoções em exclusivo
INÍCIO | MARCAS | ESTILOS | BOLSAS / MALAS | ACESSÓRIOS | NOVIDADES | PREÇOS BAIXOS | TAMANHOS GRANDES | PESQUISA | AGENDA DE TENDÊNCIAS
Quem é a SPARTOO? | F.A.Q. | As vantagens | C.G.V. | *Condições das ofertas em curso | Marketplace | Política de privacidade | Contacto
Operações em curso

Operações promocionais: Todas as nossas ofertas são válidas no limite do stock disponível.

Marcas excluídas da nossas promoções
Os códigos promocionais da SPARTOO não são válidos nas seguintes marcas: Mellow Yellow, Sendra Boots, Chie Mihara, Minnetonka, Samsonite

As reduções da campanha "christmas days" não se aplicam às marcas:
Pablosky, Ash, No Name, Schmoove, Bunker, Panama Jack, Gabor, Clarks, UGG, Mellow Yellow, Spiral, Ted Baker, Victoria, Havaianas, Tamaris, TBS, El Naturalista, Camper, Hunter, Lacoste, Sendra boots, Chie Mihara, Meindl, Primigi, Minnetonka, Timberland, Barbara Rihl, Thierry Mugler, Le Temps des cerises, IKKS, Tann's, Eastpak, Nat & Nin, Clarks, Abaco, Petite Mendigote, Arthur & Aston, Mac Douglas, Upla, Petite Mendigote, Samsonite, Hugo Boss, Freelance, Jean-Baptiste Rautureau, Versace, Michael Michael Kors, Michael Kors, Kenzo, Marc by Marc Jacobs, Les voiles de Saint Tropez, Canada Goose

Produtos Parceiro
- Os códigos promocionais da SPARTOO não são válidos nos "produtos dos parceiros".
- A entrega e a devolução podem não ser gratuitas quando os produtos estão marcados como "Produto Parceiro"

O seu navegador não aceita cookies!
Deve activá-los para aceder a todas as funcionalidades do nosso site.
Para saber como ativar os cookies, clique aqui.